@@ -2,14 +2,13 @@
 
 from werkzeug import exceptions
 
+from .wrappers import Limit
+
 
 class RateLimitExceeded(exceptions.TooManyRequests):
-    """exception raised when a rate limit is hit.
+    """Exception raised when a rate limit is hit."""
 
-    The exception results in ``abort(429)`` being called.
-    """
-
-    def __init__(self, limit):
+    def __init__(self, limit: Limit) -> None:
         self.limit = limit
 
         if limit.error_message:
@@ -20,4 +19,4 @@ class RateLimitExceeded(exceptions.TooManyRequests):
             )
         else:
             description = str(limit.limit)
-        super(RateLimitExceeded, self).__init__(description=description)
+        super().__init__(description=description)
